@@ -184,6 +184,44 @@ package_disliked (const gchar *package)
 	return retval;
 }
 
+gboolean
+package_blacklisted (const gchar *package)
+{
+	gboolean retval;
+	gchar *blacklist_file, *blacklist_packs;
+	gchar **lines;
+	gint i;
+/*	
+	if (g_file_get_contents ("/root/.dropline/cache_dir", &cache_dir, NULL, NULL))
+	{
+		newline = strstr (cache_dir, "\n");
+		if (newline)
+			cache_dir [newline - cache_dir] = '\0';
+		
+	}
+	else
+		cache_dir = g_strdup ("/var/cache/dropline-installer");
+*/	
+	blacklist_file = g_strdup ("/root/.dropline/blacklist");
+	
+	if (g_file_get_contents (blacklist_file, &blacklist_packs, NULL, NULL))
+	{
+		retval = FALSE;
+		lines = g_strsplit (blacklist_packs, "\n", MAX_FILES);
+		for (i = 0; lines [i] && lines [i][0] != '\0' && !retval; i++)
+		{
+			if (!strncmp (lines [i], package, strlen (lines [i])))
+				retval = TRUE;
+		}
+		
+		g_strfreev (lines);
+	}
+	else
+		retval = FALSE;
+	
+	return retval;
+}
+
 void
 update_parse (DroplineData *data, const gchar *mesg)
 {
@@ -246,8 +284,11 @@ update_parse (DroplineData *data, const gchar *mesg)
 				lines [i][colon - lines[i] - 2] = '\0';
 				update_log (lines[i]);
 				update_log ("\n");
-				if (!package_disliked (lines [i]))
+				if (!package_disliked (lines [i]) ||
+					!package_blacklisted (lines [i]))
+				{
 					j++;
+				}
 			}
 		}
 		
